;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; GNU GENERAL PUBLIC LICENSE ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; Patagonia PSMED is an agent-based model designed to study
;; a simple case of Evolution of Ethnic Differentiation.
;; Copyright (C) 2012, 2013
;; José I. Santos, José M. Galán & Luis R. Izquierdo
;; J.A. Barceló, F. Del Castillo, R. Del Olmo, L. Mameli, F.J. Miguel Quesada, D. Poza, X.Vila
;;
;; This research has been funded by the Spanish Ministry of Science and Innovation, through
;; Grant CSO2012-31401 (I+D+i project) and CSD2010-00034 (SimulPast CONSOLIDER-INGENIO).
;;
;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License
;; as published by the Free Software Foundation; either version 3
;; of the License, or (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.


;; PSMED  -  Patagonia Simple Model of Ethnic Differentiation
;; Version: 1.6, december 2013

breed [families family]

globals
[
  season                         ; hot or cold
  weights-vector                 ; [0.5 0.25 0.12 0.06 0.03 0.015 0.0075 0.00375 0.001875 0.0009375]
  component-index                ; counter of groups

  ;OUTPUT VARIABLES
  number-of-social-aggregates
  number-of-agents-in-social-aggregates
  number-of-isolated-agents
  number-of-agents-that-died-of-starvation
  number-of-living-agents      ;(at the beginning of the tick)
  total-collected-energy
  collected-energy-standard-deviation
  average-cultural-distance-in-aggregates
  sd-cultural-distance-in-aggregates
  largest-group-size
  number-of-movements
  total-number-of-starvation-deaths
  sum-of-labor
  mean-technology-of-families
  std-technology-of-families
]

families-own
[
  my-neighborhood       ; list of families around
  my-helpers            ; subset of my-neighborhood that will help me (with probability 95%)
  my-group              ; list of agents withins a social aggregate (i.e. families that belong to my group/component)
  group-size            ; size of the group (component) where I belong
  collected-energy      ; energy obtained during the current tick
  total-energy          ; total level of energy (including surplus)
  identity              ; 10-dimension vector with values 1 (no important) to 6 (very important)
  labor                 ; number of individuals within a household
  survival-threshold    ; 730 * labor
  technology            ; Gaussian-distributed: mean: average-technology; standard deviation: diversity
  conservation-factor   ; current value of technology divided by two
  individual-capability ; fraction of the resource that the agent is able to obtain when working on their own
  cultural-distance     ; cooperation will be posible if similarity >= cultural-distance
  cooperation?          ; true if I have been involved in a cooperation process (i.e. I have helped someone or someone has helped me)
  explored?             ; needed for detecting components
  component             ; group (i.e. component in the network) where the family belongs             
]

patches-own
[
  difficulty       ; (h)
  max-resource     ; maximum amount of resource (in hot season)
  resource         ; current amount of resource
  amount-consumed  ; amount of energy consumed during the current tick 
  exploited?       ; true during one tick after been exploited
]



to setup
  clear-all
  reset-ticks
  
  ;SET GLOBAL VARIABLES
  set weights-vector [0.5 0.25 0.12 0.06 0.03 0.015 0.0075 0.00375 0.001875 0.0009375]
  
  
  ;CREATE AND INITIALIZE FAMILIES
  
  let initial-identity n-values 10 [1 + random 5]  ;all the families start with the same identity vector
  
  ask n-of initial-population patches
  [
    sprout-families 1
    [
      set shape "person"
      set color red
      set identity initial-identity
      set labor random-poisson labor-average if labor < 2 [set labor 2] ;(correction for cases with labor < 2)
      set survival-threshold (730 * labor) / 2
      set technology random-normal average-technology diversity
          ; correction to force technology to be in the interval [0 2] (and thus depreciation will be in [0 1]
          if technology < 0.02 [set technology 0.02]
          if technology > 2 [set technology 2]
      set conservation-factor technology / 2
      set total-energy 1 + survival-threshold * (1 + conservation-factor) / conservation-factor    ; this means that all the families will have enough energy to survive the first tick without hunting
      set collected-energy 0
      set my-group families with [who < 0]     ; initialize my-group = nobody 
    ]
  ]
  
  
  ;INITIALIZE PATCHES
  ask patches
  [
    ; Resources are uniformly distributed in [max-resource-on-patches / 1000, max-resource-on-patches]
    set max-resource (max-resource-on-patches / 1000) + random ( max-resource-on-patches - (max-resource-on-patches / 1000) )
    set difficulty random-float 1
    set exploited? false
    set amount-consumed 0
    set pcolor 69
  ]
end





to go
  survive
  update-resources-on-patches
  update-cultural-distance  
  hunt-and-gather
  identify-groups
  update-identity
  update-technology
  decide-whether-to-move-or-stay
  update-output-variables
  tick
  ;if not any? families [stop]
  if ticks = 1000 or not any? families [stop]
end





to survive
  set number-of-agents-that-died-of-starvation 0
  set number-of-living-agents count families
  
  ; 1. Substract survival-threshold. If they didn't reach their survival threshold in the previous tick, their current level of total-energy will be < 0 at this point;
  ; in this case their amount of labor is reduced by one unit   
  ask families
    [
      set total-energy total-energy - survival-threshold

      if total-energy < 0
      [
        set labor labor - 1
        set survival-threshold (730 * labor) / 2 
        set total-energy 0
        
        ;if their amount of labor goes below 2, the family (agent) dies
        if labor < 2 
        [
          set number-of-agents-that-died-of-starvation number-of-agents-that-died-of-starvation + 1
          die
        ]     
      ] 
    ]
  

  ; 2. Vegatative reproduction: The amount of labor within a family goes up one unit every 6 ticks
  ask families
  [
    if ticks > 1 and remainder ticks 30 = 0
    [
      set labor labor + 1
      set survival-threshold (730 * labor) / 2 
    ]
  ]
  
  ; if the amount of labor reaches the value 10, the family is split into two families with probability 95%
  ; (provided there is enough room in the neighbourhood for another family: there cannot be more than one family in the same patch)
  ask families
  [
    if labor >= 10
    [
      if random-float 1 < .95
      [
        if any? patches in-radius movement with [not any? turtles-here]
          [
            set labor floor (labor / 2)
            set survival-threshold (730 * labor) / 2      
            hatch-families 1 [move-to one-of patches in-radius movement with [not any? turtles-here]]
          ]
      ]
    ]
  ]   
end





to update-resources-on-patches 
  set season ifelse-value (remainder ticks  2 = 0) ["hot"] ["cold"]
  ask patches
  [
    ifelse exploited?
    [
      ; patches that were exploited in the previous tick:
      ; if the current season is cold, the patch will not regenerate completely: (max-resource - amount-consumed)/2
      ; if the current season is hot, the level of resource will be max-resource (no matter whether it was exploited during the previous tick or not)
      if season = "hot" [set resource max-resource]
      if season = "cold" [set resource (max-resource - amount-consumed) / 2]
    ] 
    [
      set resource ifelse-value (season = "hot") [max-resource] [max-resource / 2] 
    ]  
    set exploited? false
    set amount-consumed 0
  ]
  ifelse (display-resorces?) [ask patches [set pcolor scale-color green resource 100000 100]] [ask patches [set pcolor 69]]  
end





to update-cultural-distance
  ask families
  [
    ifelse ([resource] of patch-here) <= survival-threshold
    [
      ; They will refuse to cooperate, as they are unable to reach their survival-threshold no matter the number of people who help them
      set cultural-distance 1 
    ]
    [
      let extra-workers max list 0 (  (survival-threshold / (difficulty * (([resource] of patch-here) - survival-threshold) ) ) ^ ( 1 / technology) - labor)  
      ; extra-workers could be negative (if I have plenty of labor to obtain my survival threshold: I don't need any help from anyone)  --> in this case extra-workers = 0
      set cultural-distance min list 1 ((1 / 100) * extra-workers) ; cultural distance could be greater than 1 if the number of extra workers goes above 100 --> --> in this case cultural distance = 1
    ]
  ]
end





to hunt-and-gather
  ask families 
  [
    set total-energy total-energy * conservation-factor ;depreciate agents' energy at the beginning of the tick 
    set cooperation? false 
    set my-helpers families with [who < 0] ; (empty agentlist)
    set my-group families with [who < 0]   ; (empty agentlist)
    set collected-energy 0
  ]
  
  ask links [die]
  

  ; families with total-energy > survival-threshold don't hunt or gather
    
  ask families with [total-energy < survival-threshold]
  [
    ; Try to act individually:
    set individual-capability calculate-individual-capability
    let productivity ([resource] of patch-here) * individual-capability
    
    ifelse cooperation-allowed?
     
    
    [
      ; FAMILIES ARE ALLOWED TO ASK FOR HELP WHENEVER THEY ARE UNABLE TO REACH THEIR SURVIVAL THRESHOLD
      ifelse productivity >= survival-threshold
      [
        ; ACT INDIVIDUALLY
        ; I don't need to cooperate: I will act individually and collect as much energy as I need to reach my survival-threshold
        
        set collected-energy min list (survival-threshold - total-energy) (individual-capability) * [resource] of patch-here  
        set total-energy total-energy + collected-energy       
        ask patch-here ;update resource on patch:
          [
            set amount-consumed [collected-energy] of myself 
            set resource resource - amount-consumed 
            set exploited? true
          ]  
      ]
      [
        ; COOPERATION (I need to ask for help)
        let capability individual-capability
        identify-neighbors ; define my-helpers (my-helpers contains a list of families that can potentially help me, i.e. our similarity is greater than their cultural-distance)
        let agents-willing-to-help ask-for-help
        if length agents-willing-to-help > 0 ; if someone helps me, my capability will be aggregated-capability. Otherwise it will be my individual-capability
        [
          set capability calculate-aggregated-capability agents-willing-to-help
        ]

        set collected-energy ([resource] of patch-here) * capability
        
        set total-energy total-energy + collected-energy        ;(therefore, total-energy might be greater than her survival-threshold   
        
        ;update resource on patch:
        ask patch-here
          [
            set amount-consumed [collected-energy] of myself 
            set resource resource - amount-consumed 
            set exploited? true
          ]  
      ]  
    ]
    
    
    
    [
      ; FAMILIES ARE NOT ALLOWED TO ASK FOR HELP IF THEY ARE UNABLE TO REACH THEIR SURVIVAL THRESHOLD. THEY WILL ACT INDIVIDUALLY

      set collected-energy min list (survival-threshold - total-energy) (individual-capability) * [resource] of patch-here
      set total-energy total-energy + collected-energy        
      ask patch-here ;update resource on patch:
          [
            set amount-consumed [collected-energy] of myself 
            set resource resource - amount-consumed 
            set exploited? true
          ]  
    ]   
  ]
end





to-report calculate-individual-capability
  report 1 / (1 + (1 / (([difficulty] of patch-here) * (labor ^ technology))))
end





to-report ask-for-help
  ; Determine the list of agents that are willing to cooperate 
  let agents-willing-to-cooperate []
  if count my-helpers > 0  ; if my list of helpers is not empty 
  [
    ;each one of my helpers will help me with p=95%
    foreach [self] of my-helpers
    [
      if random-float 1 < 0.95  
      [
        set agents-willing-to-cooperate fput ? agents-willing-to-cooperate  
      ]
    ]
    ; The agents contained in the list agents-willing-to-cooperate will help me
    ask turtle-set agents-willing-to-cooperate [create-link-with myself]   ;helpers create a link with helped agents
    ask links [set color black set thickness .1] 
    set cooperation? true ; I have cooperated...
    ask turtle-set agents-willing-to-cooperate [set cooperation? true]  ; ... and so have my helpers
  ]
  report agents-willing-to-cooperate
end




to-report calculate-aggregated-capability [agents-willing-to-cooperate]  
  let max-technology-within-my-local-group max [technology] of (turtle-set agents-willing-to-cooperate self)   ; maximum technology within my group (including myself)  
  let returns-to-cooperation 2 - ([resource] of patch-here / max-resource-on-patches)                   
  let total-labor labor + sum [labor] of turtle-set agents-willing-to-cooperate                                  ; total labor within my group (including myself)
  let aggregated-capability 1 / (1 + ( 1 / ( ( ([difficulty] of patch-here) * (total-labor ^ max-technology-within-my-local-group)) ^ returns-to-cooperation ) ) )                        
  report aggregated-capability
end





to identify-neighbors
  set my-neighborhood other families-on patches in-radius movement
  set my-helpers my-neighborhood with [(get-similarity identity ([identity] of myself)) > cultural-distance ] ; cultural-distance of my neighbors'
end





to-report get-similarity [a b]
  let ap (map [?1 * ?2] a weights-vector)
  let bp (map [?1 * ?2] b weights-vector)
  let numerator sum (map [?1 * ?2] ap bp)
  let denominator sqrt((sum map [? * ?] ap)) * sqrt((sum map [? * ?] bp))                     
  report numerator / denominator
end





to identify-groups
  find-all-components
  ask families with [component > 0]
  [
    set my-group families with [component = [component] of myself]
    set group-size count my-group
  ] 
end





;; The following two procedures are an adaptation from: Wilensky, U. (2005). NetLogo Giant Component model. 
;; http://ccl.northwestern.edu/netlogo/models/GiantComponent. 
;; Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
to find-all-components
  ask families [set explored? false set group-size 0]
  ask families with [not any? link-neighbors] [set component 0 set explored? true] ; families that don't cooperate (isolated agents) will have component = 0
  set component-index 0
  loop
  [ ifelse any? families with [not explored?]
      [ 
        let start one-of sort families with [ not explored? ]
        set component-index ( component-index + 1)
        ask start [ explore ]  
      ]
      [stop]
  ] 
end

;; Finds all families reachable from this node
to explore 
  if explored? [stop]
  set explored? true
  set component component-index
  ask link-neighbors [explore]
end
  




to decide-whether-to-move-or-stay
  ask families
  [
    ; 1. Calculate if I will be able to survive one more tick with my current level of energy (bearing in mind the depreciation factor) without working.
    ; If that is the case, I leave with probability 0.05
    ifelse (total-energy - survival-threshold) * conservation-factor > survival-threshold
    [
      if (random-float 1 < 0.05) [move] 
    ]
    [
      ; 2. I will have to work next tick because I will not be able to get by with my (depreciated) level of energy 
      ; Before moving, I will check if I will be able to get enough resources if I stay in the same patch
      let resources-next-tick ifelse-value (season = "hot") [([max-resource] of patch-here - collected-energy) / 2] [[max-resource] of patch-here]
      ifelse resources-next-tick * individual-capability  > survival-threshold
      [
        ; If I can survive here, I will probably stay, but I will leave with probability 0.05 
        if (random-float 1 < 0.05) [move]
      ]
      [
        move
      ] 
    ]
  ]
end  




to move
  if any? patches in-radius movement with [not any? turtles-here]
  [
    set number-of-movements number-of-movements + 1
    move-to one-of patches in-radius movement with [not any? turtles-here]
  ]
end





to update-identity
  ; 1. Diffusion process (only for agents that have cooperated)
  
  if any? families
  [
    let group-index n-values component-index [1 + ?]
    foreach group-index
    [
      let consensual-identity compute-consensual-identity families with [component = ?]
      ask families with [component = ?]
      [
        if random-float 1 < 0.95 [set identity consensual-identity]
      ]   
    ]
  ]
  
  
  
  ; 2. Mutation process (for all families)
  ask families
  [
    if random-float 1 < internal-change-rate
    [
      let index-vector n-values 10 [?]
      foreach index-vector
        [
          if random-float 1 >= (item ? weights-vector) [set identity replace-item ? identity (1 + random 5)]
        ]
    ]  
  ]  
end





to-report compute-consensual-identity [group]
  let consensus []
  foreach n-values 10 [?]
    [ 
      let consensual-trait one-of modes [ item ? identity] of group
      set consensus fput consensual-trait consensus
    ]
  set consensus reverse consensus
  report consensus  
end
  
    



to update-technology
  if any? families
  [
    ; 1. Diffusion process (only for agents that have cooperated)
    let group-index n-values component-index [1 + ?]
    foreach group-index
    [
      let this-group families with [component = ?]
      let average-technology-this-group mean [technology] of this-group
      ask this-group
      [
        ifelse technology < 0.95 * average-technology-this-group
        [
          if random-float 1 < 0.95 
          [
            set technology technology + 0.1 
            if technology > max [technology] of this-group [set technology max [technology] of this-group]
          ]
        ]
        [
          if technology < 1.05 * average-technology-this-group
            [
              if random-float 1 < 0.95
              [
                set technology technology + 0.01
                if technology > max [technology] of this-group [set technology max [technology] of this-group]
              ]
            ]
        ] 
      ]
      ask this-group [set conservation-factor technology / 2]
    ]
  ]
  
  
  
  ; 2. Mutation process (for all families)
  ask families
  [
    if random-float 1 < internal-change-rate
    [
      set technology random-normal average-technology diversity
      ; possible correction to force technology to be in the interval [0 2] (and thus depreciation will be in [0 1]
      if technology < 0.02 [set technology 0.02]
      if technology > 2 [set technology 2]
      set conservation-factor technology / 2
    ]
  ]  
end






to update-output-variables
  set number-of-social-aggregates component-index
  set number-of-agents-in-social-aggregates count families with [cooperation?]
  set number-of-isolated-agents count families with [not cooperation?]
  set largest-group-size ifelse-value any? (families with [group-size > 1]) [[group-size] of one-of families with-max [group-size]] ["N/A"]   
  set total-collected-energy ifelse-value (any? families) [sum [collected-energy] of families] [0]
  set collected-energy-standard-deviation ifelse-value (count families >= 2) [standard-deviation [collected-energy] of families] [0] 
  set average-cultural-distance-in-aggregates ifelse-value any? (families with [component > 0]) [mean [cultural-distance] of families with [component > 0]] ["N/A"]
  set sd-cultural-distance-in-aggregates ifelse-value any? (families with [component > 0]) [standard-deviation [cultural-distance] of families with [component > 0]] ["N/A"]
  set total-number-of-starvation-deaths total-number-of-starvation-deaths + number-of-agents-that-died-of-starvation
  set sum-of-labor sum [labor] of families
  if count families >= 2
  [
    set mean-technology-of-families mean [technology] of families
    set std-technology-of-families  standard-deviation [technology] of families
  ]   
end 


  
  

















   
@#$#@#$#@
GRAPHICS-WINDOW
8
71
1058
622
-1
-1
13.0
1
30
1
1
1
0
0
0
1
0
79
0
39
0
0
0
ticks
30.0

BUTTON
733
31
837
64
SETUP
setup
NIL
1
T
OBSERVER
NIL
S
NIL
NIL
1

BUTTON
843
31
947
64
GO (one tick)
go 
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
953
31
1057
64
GO
go
T
1
T
OBSERVER
NIL
G
NIL
NIL
1

SLIDER
8
622
180
655
initial-population
initial-population
2
3200
300
1
1
NIL
HORIZONTAL

SLIDER
352
622
524
655
labor-average
labor-average
2
20
4
1
1
NIL
HORIZONTAL

SLIDER
180
622
352
655
average-technology
average-technology
0.02
2
0.22
0.1
1
NIL
HORIZONTAL

SLIDER
180
655
352
688
diversity
diversity
0
1
0.5
.1
1
NIL
HORIZONTAL

SLIDER
352
654
524
687
internal-change-rate
internal-change-rate
0
1
0.05
.01
1
NIL
HORIZONTAL

MONITOR
128
26
252
71
SEASON
season
17
1
11

MONITOR
8
26
128
71
CYCLE
max list 0 (ticks - 1)
17
1
11

MONITOR
1063
302
1304
347
Number of agents in social aggregates
number-of-agents-in-social-aggregates
17
1
11

SWITCH
869
620
1058
653
display-resorces?
display-resorces?
1
1
-1000

MONITOR
1063
347
1304
392
Number of social aggregates
number-of-social-aggregates
17
1
11

MONITOR
1304
302
1545
347
Number of isolated agents
number-of-isolated-agents
17
1
11

MONITOR
1304
346
1545
391
Number of agents within the largest group
largest-group-size
17
1
11

MONITOR
1061
133
1302
178
Number of starvation deaths (current tick)
number-of-agents-that-died-of-starvation
17
1
11

MONITOR
1061
89
1302
134
Agents at the beginning of the tick
number-of-living-agents
17
1
11

MONITOR
1062
471
1303
516
Total collected energy
total-collected-energy
2
1
11

MONITOR
1302
471
1543
516
Standard deviation of collected energy
collected-energy-standard-deviation
2
1
11

MONITOR
1063
391
1304
436
Average cultural distance in aggregates
average-cultural-distance-in-aggregates
3
1
11

MONITOR
1301
89
1542
134
Agents at the end of the tick
count families
17
1
11

MONITOR
1304
391
1545
436
Std. deviation of cultural distance in aggregates
sd-cultural-distance-in-aggregates
3
1
11

TEXTBOX
1253
278
1403
296
GROUP STATISTICS
14
0.0
1

TEXTBOX
1237
67
1387
85
SURVIVAL STATISTICS
14
0.0
1

TEXTBOX
1245
448
1395
466
ENERGY STATISTICS
14
0.0
1

SWITCH
555
31
728
64
cooperation-allowed?
cooperation-allowed?
0
1
-1000

BUTTON
1549
90
1744
123
NIL
  survive
NIL
1
T
OBSERVER
NIL
1
NIL
NIL
1

BUTTON
1549
125
1744
158
NIL
  update-resources-on-patches\n 
NIL
1
T
OBSERVER
NIL
2
NIL
NIL
1

BUTTON
1549
162
1743
195
NIL
  update-cultural-distance  \n  
NIL
1
T
OBSERVER
NIL
3
NIL
NIL
1

BUTTON
1549
198
1743
231
NIL
  hunt-and-gather\n 
NIL
1
T
OBSERVER
NIL
4
NIL
NIL
1

BUTTON
1549
236
1742
269
NIL
\n  identify-groups\n 
NIL
1
T
OBSERVER
NIL
5
NIL
NIL
1

BUTTON
1549
272
1743
305
NIL
  update-identity\n  
NIL
1
T
OBSERVER
NIL
6
NIL
NIL
1

BUTTON
1549
309
1743
342
NIL
  update-technology\n  
NIL
1
T
OBSERVER
NIL
7
NIL
NIL
1

BUTTON
1550
346
1743
379
NIL
\n  decide-whether-to-move-or-stay\n
NIL
1
T
OBSERVER
NIL
9
NIL
NIL
1

BUTTON
1549
385
1743
418
NIL
  update-output-variables\n  tick
NIL
1
T
OBSERVER
NIL
0
NIL
NIL
1

MONITOR
1302
133
1542
178
Number of starvation deaths (cumulative)
total-number-of-starvation-deaths
17
1
11

MONITOR
1061
178
1302
223
Total labor
sum-of-labor
17
1
11

SLIDER
524
621
697
654
movement
movement
1
10
5
1
1
NIL
HORIZONTAL

MONITOR
1061
222
1304
267
Mean technology of families
mean-technology-of-families
2
1
11

MONITOR
1303
222
1542
267
NIL
std-technology-of-families
2
1
11

SLIDER
8
655
180
688
max-resource-on-patches
max-resource-on-patches
10000
100000
20000
10000
1
NIL
HORIZONTAL

TEXTBOX
9
696
380
738
min-resource-on-patches = max-resource-on-patches / 1000
11
0.0
1

MONITOR
1304
179
1544
224
labor per agent
mean [labor] of families
2
1
11

MONITOR
1063
519
1544
564
Collected energy per labor
total-collected-energy / sum [labor] of families
2
1
11

TEXTBOX
9
10
254
28
Patagonia PSMED v1.6 (dec. 2013)
11
0.0
1

@#$#@#$#@
## PSMED  -  Patagonia Simple Model of Ethnic Differentiation
Version: 1.6, december 2013

## MOTIVATION: ETHNICITY AS CULTURAL DIFFERENTIATION

An ethnic group is a group of people whose members explicitly regard themselves and are regarded by others as truly distinctive, through a common heritage that is real or assumed- sharing “cultural” characteristics. Members of an ethnic group are conscious of belonging to an ethnic group. Processes that result in the emergence of such identification are called ethnogenesis.

Ethnic groups are usually expressed as a set of shared norms, transmitted through believes, religion, language. The similarity in language and material culture is the obvious consequence of people that work together and have common goals. The more cultural transmission among individuals connected by the same social network, the more similar are the agents, their actions and the material and immaterial consequences of their actions.

## MAIN HYPOTESES

We consider a constant population of agents (households), moving randomly in search for resources and interacting with others located in the same geographical area and belonging to the same ethnic group in order to enhance their probabilities for subsistence. Local interactions facilitates cultural diffusion and ethnic differentiation.

Main hypotheses:  
- There is a population of families that differ in their capacities to exploit environmental resources and in their cultural traits, whose number remains constant during the simulation  
- Cultural identity is modeled as a cultural-dimensions dimensional space with cultural-traits different cultural traits (see Axelrod 1997)  
- Each family moves randomly through the territory and interacts within her local environment (neighborhood) with those others regarded as similar (group). The size of the neighborhood is modulated by the global parameter neighborhood-radius. In addition, two families regard themselves as similar if their cultural proximity, measured as the relative number of cultural dimensions they share, is greater than the global parameter %cultural-proximity.  
- There are increasing returns to cooperation, i.e. families get more resources working together than individually, modulated by the global parameter returns-to-cooperation.  
Culture diffuses into population through a local imitation process. A family With probability p-cult-diffusion a family copies some trait of the mode of her group.  
- Moreover, culture evolves through local mutation. With probability p-cult-mutation a family mutates one of her cultural traits which is simultaneously copied by her group (we supposed that geographical proximity ensures that culture of all group members evolves in the same direction).

Global ethnic groups

Families do not have a global information of all ethnic groups in the population, they only can differentiate other families in their neighborhood and interact with them in consequence. So, we do not presuppose groups, only a measure of cultural proximity which makes two families regard themselves as similar. Then, groups are the result of local interactions, and we identify them using a particular abstraction of the cultural network, i.e. two families have a link if they are cultural close, and defining ethnic groups as the components of this network. 

## HOW IT WORKS

Parameters  
- initial-population: number of families
- labor-average: labor force (=people), mean to generate families distribution (min = 2)
- average-technology: tecnology multiplier, mean to generate distribution (Gaussian)
- diversity: standard deviation for average-technology distribution
- movement: maximum scope for family movement in a single timestep (tick)
- max-resource-on-patches: patch resources are uniformly distributed
  in the range ( max-resource-on-patches / 1000 , max-resource-on-patches )
- internal-change-rate: probability for the cultural vector "random mutation" engine
- display-resorces?: switch to display terrain resource levels (color-coded)
- cooperation-allowed?: switch to (de)enable cooperation


## HOW TO USE IT

Observing a simulation:  
1.Set up the model by selecting values for the parameters.  
2.Press the setup button. Families will be represented in the world.
3.Press go-step to see the results after just one time period, or press go to start a 1000 steps simulation (and press go again to halt the run). The cooperation network is depicted by means of links between families.

Monitors (system state at the end of each timestep):
- Some statistics about families, in terms of survival, labor, tecnology...
- Some statistics about groups evolution, in terms of number, size, diversity...
- Some statistics about system efficiency, in terms of agregate collected energy.

## A MORE COMPLEX PROPOSAL

There is no doubt that ethnic evolution is a complex phenomenon, and therefore it is necessary to consider more social and historical details in our particular story of ethnogenesis in hunter-gatherer groups. But, in order to reach that sort of knowledge, simple models like this one are useful to understand how diverse hypotheses operates in more complex models.

This model represents a first step in a more ambitious research project that intends to simulate social, economic and political decisions in prehistoric hunter-gatherer groups in Patagonia.

## CREDITS

Copyright (C) 2012, 2013. 
J.A. Barceló, J.A. Cuesta, F.del Castillo, R. Del Olmo, J.M. Galán, L. Mameli, F. Miguel, D. Poza, J.I. Santos, X. Vila.
Universitat Autonoma de Barcelona, Universidad Carlos III, Universitat de Girona, Universidad de Burgos, Universidad de Valladolid.

This research has been funded by the Spanish Ministry of Science and Innovation, through
Grant CSO2012-31401 (I+D+i project) and CSD2010-00034 (SimulPast CONSOLIDER-INGENIO).


GNU GENERAL PUBLIC LICENSE
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

## REFERENCES

Axlerod, R. (1997) The Dissemination of Culture: A Model with Local Convergence and Global Polarization. The Journal of Conflict Resolution, Vol. 41, No. 2, pp. 203-226.

Part of the code adapted from: Wilensky, U. (2005). NetLogo Giant Component model. http://ccl.northwestern.edu/netlogo/models/GiantComponent. 
Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Death causes" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total-number-of-starvation-deaths</metric>
    <metric>total-number-of-oldage-deaths</metric>
    <enumeratedValueSet variable="scenario">
      <value value="&quot;RICH WORLD&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-resorces?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-technology">
      <value value="1.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diversity">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cooperation-allowed?">
      <value value="false"/>
    </enumeratedValueSet>
    <steppedValueSet variable="labor-average" first="2" step="1" last="20"/>
    <enumeratedValueSet variable="internal-change-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-population">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Survival ticks" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>ticks</metric>
    <metric>number-of-living-agents</metric>
    <metric>total-number-of-starvation-deaths</metric>
    <metric>total-number-of-oldage-deaths</metric>
    <enumeratedValueSet variable="scenario">
      <value value="&quot;POOR WORLD&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diversity">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="labor-average">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="internal-change-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-population">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cooperation-allowed?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-resorces?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-technology">
      <value value="0.22"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
